pub struct CompareParams {
pub thresholds: Thresholds,
pub min_tokens: usize,
pub min_lines: usize,
}Expand description
Settings of a comparison.
Fields
thresholds: ThresholdsThe similarities the rules need, on the scale of the embedder’s model.
min_tokens: usizeFunctions with fewer detection tokens do not count and do not take part in step 1.
min_lines: usizeFunctions of fewer lines, the first and the last included, do not count and do not take part in step 1.